pub enum AttentionStrategy {
FlashBlackboxAccelerated(BlackboxAcceleratedStrategy),
FlashUnit,
Fallback,
Autotune,
}Expand description
Strategy used to select which attention implementation to run.
Variants
FlashBlackboxAccelerated(BlackboxAcceleratedStrategy)
Flash Attention using accelerated inner matmuls.
FlashUnit
Flash Attention using unit inner matmuls.
Fallback
Fallback implementation using multiple separate kernels.
Autotune
Available on crate feature
autotune only.Automatically benchmark and select the best strategy at runtime.