Module fft

Module fft 

FFT algorithms

Functions

irfft
Launch the irfft kernel with optional padding for non-power-of-two sizes.
rfft
Launch the rfft kernel with optional padding for non-power-of-two sizes.