pub fn cast<R: CubeRuntime>(input: CubeTensor<R>, dtype: DType) -> CubeTensor<R>Expand description
Cast a tensor to the given element type.
Note: When input element is semantically a boolean, prefer bool_cast function.
pub fn cast<R: CubeRuntime>(input: CubeTensor<R>, dtype: DType) -> CubeTensor<R>Cast a tensor to the given element type.
Note: When input element is semantically a boolean, prefer bool_cast function.